import { Identifiable } from "@/data";
import { Page } from "@/data/page";
import { Transformer } from "@/serialization";

export interface PageDTO extends Identifiable {
    accessName: string;
    title: string;
    titleEng: string;
    content: string;
    contentEng: string;
}

export const pageDtoTransformer: Transformer<PageDTO, Page> = {
    reverseTransform(subject: Page, context: undefined): PageDTO {
        return {
            id: subject.id,
            accessName: subject.slug,
            content: subject.content.pl,
            contentEng: subject.content.en,
            title: subject.title.pl,
            titleEng: subject.title.en,
        }
    },
    transform(subject: PageDTO, context: undefined): Page {
        return {
            slug: subject.accessName,
            id: subject.id,
            content: {
                pl: subject.content,
                en: subject.contentEng
            },
            title: {
                pl: subject.title,
                en: subject.titleEng
            },
        };
    }
}

export default pageDtoTransformer;
