import Axios from "axios";
import store from "@/state/store"
import { AppState } from "@/state/reducer";
import { UserState } from "@/state/reducer/user";

import * as user from "./user";
import * as edition from "./edition";
import * as page from "./page"

export const axios = Axios.create({
    baseURL: process.env.API_BASE_URL || "https://system-praktyk.stg.kadet.net/api/",
})

axios.interceptors.request.use(config => {
    const state = store.getState() as AppState;
    const user = state.user as UserState;

    if (!user.loggedIn) {
        return config;
    }

    return {
        ...config,
        headers: {
            ...config.headers,
            Authorization: `Bearer ${ user.token }`
        }
    }
})

const api = {
    user,
    edition,
    page
}

export default api;

