import React, { ReactComponentElement } from "react";
import { MainPage } from "@/pages/main";
import { RouteProps } from "react-router-dom";
import { InternshipProposalFormPage, InternshipProposalPreviewPage } from "@/pages/internship/proposal";
import { FallbackPage } from "@/pages/fallback";
import SubmitPlanPage from "@/pages/internship/plan";
import { UserLoginPage } from "@/pages/user/login";
import { RegisterEditionPage } from "@/pages/edition/register";

type Route = {
    name?: string;
    content: () => ReactComponentElement<any>,
    condition?: () => boolean,
} & RouteProps;

export const routes: Route[] = [
    { name: "home", path: "/", exact: true, content: () => <MainPage/> },

    // edition
    { name: "edition_register", path: "/edition/register", exact: true, content: () => <RegisterEditionPage/> },

    // internship
    { name: "internship_proposal", path: "/internship/proposal", exact: true, content: () => <InternshipProposalFormPage/> },
    { name: "internship_proposal_preview", path: "/internship/preview/proposal", exact: true, content: () => <InternshipProposalPreviewPage/> },
    { name: "internship_plan", path: "/internship/plan", exact: true, content: () => <SubmitPlanPage/> },

    // user
    { name: "user_login", path: "/user/login", content: () => <UserLoginPage /> },

    // fallback route for 404 pages
    { name: "fallback", path: "*", content: () => <FallbackPage/> }
]

const routeNameMap = new Map(routes.filter(({ name }) => !!name).map(({ name, path }) => [name, path instanceof Array ? path[0] : path])) as Map<string, string>

export type URLParams = { [param: string]: string };

export const prepare = (url: string, params: URLParams) => Object
    .entries(params)
    .reduce((url, [name, value]) => url.replace(`:${ name }`, value), url)

export function route(name: string, params: URLParams = {}) {
    const url = routeNameMap.get(name) || "";

    return prepare(url, params)
}

export const query = (url: string, params: URLParams) => {
    const query = Object.entries(params).map(([ name, value ]) => `${name}=${encodeURIComponent(value)}`).join("&");

    return url + (query.length > 0 ? `?${query}` : '');
}
