import { InternshipPlanAction, InternshipPlanActions } from "@/state/actions";
import { Plan } from "@/data";
import { Serializable } from "@/serialization/types";
import {
    createSubmissionReducer,
    defaultDeanApprovalsState,
    defaultSubmissionState,
    MayRequireDeanApproval,
    SubmissionState
} from "@/state/reducer/submission";
import { Reducer } from "react";
import { SubmissionAction } from "@/state/actions/submission";

export type InternshipPlanState = SubmissionState & MayRequireDeanApproval & {
    plan: Serializable<Plan> | null;
}

const defaultInternshipPlanState: InternshipPlanState = {
    ...defaultDeanApprovalsState,
    ...defaultSubmissionState,
    plan: null,
}

export const getInternshipPlan = ({ plan }: InternshipPlanState): Plan | null => plan;

const internshipPlanSubmissionReducer: Reducer<InternshipPlanState, InternshipPlanAction> = createSubmissionReducer({
    [InternshipPlanActions.Approve]: SubmissionAction.Approve,
    [InternshipPlanActions.Decline]: SubmissionAction.Decline,
    [InternshipPlanActions.Receive]: SubmissionAction.Receive,
    [InternshipPlanActions.Save]: SubmissionAction.Save,
    [InternshipPlanActions.Send]: SubmissionAction.Send,
})

const internshipPlanReducer = (state: InternshipPlanState = defaultInternshipPlanState, action: InternshipPlanAction): InternshipPlanState => {
    state = internshipPlanSubmissionReducer(state, action);

    switch (action.type) {
        case InternshipPlanActions.Save:
        case InternshipPlanActions.Send:
            return {
                ...state,
                plan: action.plan,
            }
        default:
            return state;
    }
}

export default internshipPlanReducer;
